{% extends "base.html" %} {% load i18n %} {% load cms_tags sekizai_tags %} {% block headerdesc %}{{ object.excerpt }}{% endblock %} {% block content %} {% addtoblock 'css' %} {% endaddtoblock %} {% include "news/translation_option.html" %}

# {% block title %}{{ object.title }}{% endblock %}

{{ object.pub_date }}

{% if not object.is_published %}
{% trans "This article is not published yet!" %}
{% endif %} {{ object.content|safe }} {% endblock %}